@@ -36,9 +36,9 @@ class ServiceStatusSchema(ma.Schema):
     tier_name = ma.fields.Str(description="Name of this tier")
     tenant_name = ma.fields.Str(description="Name of the current tenant")
     server_time = ma.fields.DateTime(description="Current wallclock time of the server machine")
-    tenants = ma.fields.Dict(description="Information about tenants")
+    tenants = ma.fields.List(ma.fields.Str(description="Information about tenants"))
     platform = ma.fields.Dict(description="Information about the platform")
-    config_dump = ma.fields.Dict(description="Dump of the entire Flask config")
+    config_dump = ma.fields.Str(description="Dump of the entire Flask config")
     default_tenant = ma.fields.Str(description="Default tenant name")
     request_headers = ma.fields.Dict(description="Request headers (debug only)")
     request_object = ma.fields.Dict(description="Request object info (debug only)")
